Django-pandas is written and maintained by Christopher Clarke and
various contributors:

Development Lead
````````````````

- Christopher Clarke <cclarke@chrisdev.com>

Contributions
``````````````
- Bertrand Bordage <bordage.bertrand@gmail.com>
- Yuval Langer <http://yuvallanger.github.io>
- Guillaume Thomas <guillaume.thomas642@gmail.com>
- Victor Novais <victorh.novaisr@gmail.com>
- Parbhat Puri  <https://parbhatpuri.com/>
- Fredrik Burman (coachHIPPO) <https://www.coachhippo.com>
